/*****************************************************************************
 *****************************************************************************
 Copyright (c) 1999 - 2000, Intel Corporation 

 All rights reserved.

 Redistribution and use in source and binary forms, with or without 
 modification, are permitted provided that the following conditions are met:

 1. Redistributions of source code must retain the above copyright notice, 
    this list of conditions and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright notice,
    this list of conditions and the following disclaimer in the documentation 
    and/or other materials provided with the distribution.

 3. Neither the name of Intel Corporation nor the names of its contributors 
    may be used to endorse or promote products derived from this software 
    without specific prior written permission.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
 AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED. IN NO EVENT SHALL CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
 LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
 NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 

 *****************************************************************************
 ****************************************************************************/

 /***************************************************************************
 **                                                                        **
 ** INTEL CORPORATION                                                      **
 **                                                                        **
 ** This software is supplied under the terms of the license included      **
 ** above.  All use of this software must be in accordance with the terms  **
 ** of that license.                                                       **
 **                                                                        **
  **  Module Name:                                                          **
 **    incg_gp_mem.c                                                       **
 **                                                                        **
 **  Abstract:                                                             ** 
 **    This module handles memory allocation and freeing for iANS.         **
 **                                                                        **
 **  Environment:                                                          **
 **    Kernel Mode (linux 2.2.x, 2.4.x)                                    **
 **                                                                        **
 ***************************************************************************/

//////////////////////////////////////////////////////////
//must allways stay the first lines in the file!
#ifdef MODVERSIONS
#include <linux/modversions.h>
#endif MODVERSIONS
//////////////////////////////////////////////////////////

#include <linux/malloc.h>
#include "incg_gp_mem.h"

#ifndef MEM_DEBUG

void iNCGGPSizedMemAlloc(void **ppObj,int Size)
{
  *(ppObj) = kmalloc ( (Size), GFP_ATOMIC );
}

void iNCGGPSizedMemFree(void **ppObj,int Size)
{
  if(*(ppObj)) {
    kfree ( (void *)(*(ppObj)));
    *(ppObj) = NULL;
  }
}

void iNCGGPMemFree(void **ppObj)
{
  if(*(ppObj)) {
    kfree ( (void *)(*(ppObj)));
    *(ppObj) = NULL;
  }
}

#else

static int alloc_count = 0;

void iNCGGPSizedMemAlloc2(void **ppObj,int Size)
{
  *(ppObj) = kmalloc ( (Size), GFP_ATOMIC );
  if(*(ppObj)) {
    alloc_count++;
    printk("Alloc: count = %d\n", alloc_count);
  }
}

void iNCGGPSizedMemFree2(void **ppObj,int Size)
{
  if(*(ppObj)) {
    alloc_count--;
    kfree ( (void *)(*(ppObj)));
    *(ppObj) = NULL;
    printk("Free: count = %d\n", alloc_count);
  }
}

void iNCGGPMemFree2(void **ppObj)
{
  if(*(ppObj)) {
    alloc_count--;
    kfree ( (void *)(*(ppObj)));
    *(ppObj) = NULL;
    printk("Free: count = %d\n", alloc_count);
  }
}

int iNCGGPMemGetAllocCount(void){
  return alloc_count;
}

#endif





